# TestCasePdfPart


## Enum

* `HEADER` (value: `'header'`)

* `TITLE` (value: `'title'`)

* `DETAILS` (value: `'details'`)

* `FOOTER` (value: `'footer'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


